Loss

Enum Loss 

pub enum Loss {
    MSE,
    SoftmaxAndCrossEntropy,
    BinaryCrossEntropy,
}

Variants



MSE

Mean Squared Error, defined as 0.5*(y_true - y_pred)^2, with the derivative being (y_pred - y_true). This is the textbook definition, but is different to keras and other frameworks which has derivative as 2(y_pred - y_true).



SoftmaxAndCrossEntropy

Will apply Softmax, then compute multi-class cross-entropy with the derivative wrt to logits being y_pred - y_true



BinaryCrossEntropy

Will apply Sigmoid, then compute binary cross-entropy with the derivative wrt to logits being y_pred - y_true

Implementations

Source

impl Loss

pub fn gradient( &self, outputs: &Array2<f32>, target: &Array2<f32>, ) -> Array2<f32>

calc gradient for each example